# monogusa (= lazy in Japanese)
Python utilities for machine learning and digital signal processing

<!-- batges -->
![CI](https://github.com/ywatanabe1989/mngs/actions/workflows/pypi_latest.yml/badge.svg)
![CI](https://github.com/ywatanabe1989/mngs/actions/workflows/latest_release.yml/badge.svg)
![CI](https://github.com/ywatanabe1989/mngs/actions/workflows/develop.yml/badge.svg)

<!-- logo -->
<div style="text-align: center;">
    <img src="./docs/lazy_python.gif" alt="Lazy Python" width="200px">
</div>


## Installation
``` bash
# Pypi latest
$ pip install mngs 

# Develop
$ pip install git+https://github.com/ywatanabe1989/mngs.git@develop
```



## Example Usages
- [`mngs.io`](https://github.com/ywatanabe1989/mngs/tree/main/src/mngs/io#readme) Input / Output
- [`mngs.path`](https://github.com/ywatanabe1989/mngs/tree/main/src/mngs/path#readme) Path
- [`mngs.dsp`](https://github.com/ywatanabe1989/mngs/tree/main/src/mngs/dsp#readme) Digital Signal Processing
- [`mngs.res`](https://github.com/ywatanabe1989/mngs/tree/main/src/mngs/res#readme) Resource
- mngs.general
- mngs.plt
- mngs.ml
- mngs.stats

## Contact
Yusuke Watanabe (ywata1989@gmail.com).


